@@ -83,13 +83,13 @@ enum : int {
     SBK_QtQuickWidgets_IDX_COUNT                             = 3
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtQuickWidgetsTypes;
+extern PyTypeObject **SbkPySide2_QtQuickWidgetsTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtQuickWidgetsModuleObject;
+extern PyObject *SbkPySide2_QtQuickWidgetsModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtQuickWidgetsTypeConverters;
+extern SbkConverter **SbkPySide2_QtQuickWidgetsTypeConverters;
 
 // Converter indices
 enum : int {
@@ -106,9 +106,12 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QQuickWidget::ResizeMode >() { return SbkPySide2_QtQuickWidgetsTypes[SBK_QQUICKWIDGET_RESIZEMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQuickWidget::Status >() { return SbkPySide2_QtQuickWidgetsTypes[SBK_QQUICKWIDGET_STATUS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QQuickWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtQuickWidgetsTypes[SBK_QQUICKWIDGET_IDX]); }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QQuickWidget::ResizeMode >() { return SbkPySide2_QtQuickWidgetsTypes[SBK_QQUICKWIDGET_RESIZEMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQuickWidget::Status >() { return SbkPySide2_QtQuickWidgetsTypes[SBK_QQUICKWIDGET_STATUS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQuickWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickWidgetsTypes[SBK_QQUICKWIDGET_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
